bayespropestimation package
===========================

Submodules
----------

bayespropestimation.bayespropestimation module
----------------------------------------------

.. automodule:: bayespropestimation.bayespropestimation
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: bayespropestimation
   :members:
   :undoc-members:
   :show-inheritance:
